@@ -1,7 +1,5 @@
 package Email::Sender::Transport::SMTP::TLS;
-{
-    $Email::Sender::Transport::SMTP::TLS::VERSION = '0.14';
-}
+$Email::Sender::Transport::SMTP::TLS::VERSION = '0.16';
 
 # ABSTRACT: Email::Sender with L<Net::SMTP::TLS> (Eg. Gmail)
 
@@ -159,13 +157,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Sender::Transport::SMTP::TLS - Email::Sender with L<Net::SMTP::TLS> (Eg. Gmail)
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -206,9 +206,7 @@ version 0.14
 
 =head1 DESCRIPTION
 
-L<Email::Sender> replaces the old and sometimes problematic L<Email::Send> library, while this module replaces the L<Email::Send::SMTP::TLS>.
-
-It is still alpha, but it works. use it at your own risk!
+DEPRECATED! Please use L<Email::Sender::Transport::SMTP> instead.
 
 =head2 ATTRIBUTES
 
@@ -242,7 +240,7 @@ Fayland Lam <fayland@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Fayland Lam.
+This software is copyright (c) 2017 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
